Crate ltrait_ui_tui

Crate ltrait_ui_tui 

Modules

style
style contains the primitives used to control how your user interface will look.

Structs

Tui
TuiConfig
TuiEntry
<SelectingStatus> <icon> <title> <sub_string> SelectingStatus in above is a char

Enums

Action
Viewport
Represents the viewport of the terminal. The viewport is the area of the terminal that is currently visible to the user. It can be either fullscreen, inline or fixed.

Functions

sample_keyconfig