Viewport

Enum Viewport 

pub enum Viewport {
    Fullscreen,
    Inline(u16),
    Fixed(Rect),
}
Represents the viewport of the terminal. The viewport is the area of the terminal that is currently visible to the user. It can be either fullscreen, inline or fixed.

When the viewport is fullscreen, the whole terminal is used to draw the application.

When the viewport is inline, it is drawn inline with the rest of the terminal. The height of the viewport is fixed, but the width is the same as the terminal width.

When the viewport is fixed, it is drawn in a fixed area of the terminal. The area is specified by a Rect.

See Terminal::with_options for more information.

Variants



Fullscreen

The viewport is fullscreen



Inline(u16)

The viewport is inline with the rest of the terminal.

The viewport’s height is fixed and specified in number of lines. The width is the same as the terminal’s width. The viewport is drawn below the cursor position.



Fixed(Rect)

The viewport is drawn in a fixed area of the terminal. The area is specified by a Rect.