Color

Enum Color 

pub enum Color {
Show 19 variants Reset, Black, Red, Green, Yellow, Blue, Magenta, Cyan, Gray, DarkGray, LightRed, LightGreen, LightYellow, LightBlue, LightMagenta, LightCyan, White, Rgb(u8, u8, u8), Indexed(u8),
}
ANSI Color

All colors from the ANSI color table are supported (though some names are not exactly the same).

Color NameColorForegroundBackground
blackColor::Black3040
redColor::Red3141
greenColor::Green3242
yellowColor::Yellow3343
blueColor::Blue3444
magentaColor::Magenta3545
cyanColor::Cyan3646
gray*Color::Gray3747
darkgray*Color::DarkGray90100
lightredColor::LightRed91101
lightgreenColor::LightGreen92102
lightyellowColor::LightYellow93103
lightblueColor::LightBlue94104
lightmagentaColor::LightMagenta95105
lightcyanColor::LightCyan96106
white*Color::White97107
  • gray is sometimes called white - this is not supported as we use white for bright white
  • gray is sometimes called silver - this is supported
  • darkgray is sometimes called light black or bright black (both are supported)
  • white is sometimes called light white or bright white (both are supported)
  • we support bright and light prefixes for all colors
  • we support - and _ and as separators for all colors
  • we support both gray and grey spellings

From<Color> for Style is implemented by creating a style with the foreground color set to the given color. This allows you to use colors anywhere that accepts Into<Style>.

Example

use std::str::FromStr;

use ratatui::style::Color;

assert_eq!(Color::from_str("red"), Ok(Color::Red));
assert_eq!("red".parse(), Ok(Color::Red));
assert_eq!("lightred".parse(), Ok(Color::LightRed));
assert_eq!("light red".parse(), Ok(Color::LightRed));
assert_eq!("light-red".parse(), Ok(Color::LightRed));
assert_eq!("light_red".parse(), Ok(Color::LightRed));
assert_eq!("lightRed".parse(), Ok(Color::LightRed));
assert_eq!("bright red".parse(), Ok(Color::LightRed));
assert_eq!("bright-red".parse(), Ok(Color::LightRed));
assert_eq!("silver".parse(), Ok(Color::Gray));
assert_eq!("dark-grey".parse(), Ok(Color::DarkGray));
assert_eq!("dark gray".parse(), Ok(Color::DarkGray));
assert_eq!("light-black".parse(), Ok(Color::DarkGray));
assert_eq!("white".parse(), Ok(Color::White));
assert_eq!("bright white".parse(), Ok(Color::White));

Variants



Reset

Resets the foreground or background color



Black

ANSI Color: Black. Foreground: 30, Background: 40



Red

ANSI Color: Red. Foreground: 31, Background: 41



Green

ANSI Color: Green. Foreground: 32, Background: 42



Yellow

ANSI Color: Yellow. Foreground: 33, Background: 43



Blue

ANSI Color: Blue. Foreground: 34, Background: 44



Magenta

ANSI Color: Magenta. Foreground: 35, Background: 45



Cyan

ANSI Color: Cyan. Foreground: 36, Background: 46



Gray

ANSI Color: White. Foreground: 37, Background: 47

Note that this is sometimes called silver or white but we use white for bright white



DarkGray

ANSI Color: Bright Black. Foreground: 90, Background: 100

Note that this is sometimes called light black or bright black but we use dark gray



LightRed

ANSI Color: Bright Red. Foreground: 91, Background: 101



LightGreen

ANSI Color: Bright Green. Foreground: 92, Background: 102



LightYellow

ANSI Color: Bright Yellow. Foreground: 93, Background: 103



LightBlue

ANSI Color: Bright Blue. Foreground: 94, Background: 104



LightMagenta

ANSI Color: Bright Magenta. Foreground: 95, Background: 105



LightCyan

ANSI Color: Bright Cyan. Foreground: 96, Background: 106



White

ANSI Color: Bright White. Foreground: 97, Background: 107 Sometimes called bright white or light white in some terminals



Rgb(u8, u8, u8)

An RGB color.

Note that only terminals that support 24-bit true color will display this correctly. Notably versions of Windows Terminal prior to Windows 10 and macOS Terminal.app do not support this.

If the terminal does not support true color, code using the TermwizBackend will fallback to the default text color. Crossterm and Termion do not have this capability and the display will be unpredictable (e.g. Terminal.app may display glitched blinking text). See https://github.com/ratatui/ratatui/issues/475 for an example of this problem.

See also: https://en.wikipedia.org/wiki/ANSI_escape_code#24-bit



Indexed(u8)

Implementations

Source

impl Color

pub const fn from_u32(u: u32) -> Color

Convert a u32 to a Color

The u32 should be in the format 0x00RRGGBB.